"""
Permission services for Bivouac Framework.

This package provides role-based access control (RBAC) functionality.
"""

from .permission_service import PermissionService

__all__ = ['PermissionService'] 